@@ -49,7 +49,7 @@ function (X, n.comp, alg.typ = c("parallel","deflation"),
         if (verbose) cat("Whitening\n")
         V <- X %*% t(X)/n
        
-        s <- La.svd(V,method="dgesdd")
+        s <- La.svd(V, method="dgesdd")
         D <- diag(c(1/sqrt(s$d)))
         
         K <- D %*% t(s$u)
@@ -99,8 +99,8 @@ function (X, n.comp, alg.typ = c("parallel","deflation"),
 ica.R.def <-
     function (X, n.comp, tol, fun, alpha, maxit, verbose, w.init)
 {
-        if (verbose && fun == "logcosh") cat("Defaltion FastICA using logcosh approx. to neg-entropy function\n")
-        if (verbose && fun =="exp") cat("Defaltion FastICA using exponential approx. to neg-entropy function\n")
+        if (verbose && fun == "logcosh") cat("Deflation FastICA using logcosh approx. to neg-entropy function\n")
+        if (verbose && fun =="exp") cat("Deflation FastICA using exponential approx. to neg-entropy function\n")
     n <- nrow(X)
     p <- ncol(X)
     W <- matrix(0, n.comp, n.comp)
@@ -185,7 +185,7 @@ ica.R.par <- function (X, n.comp, tol, fun, alpha, maxit, verbose, w.init)
     n <- nrow(X)
     p <- ncol(X)
     W <- w.init
-    sW <- La.svd(W)
+    sW <- La.svd(W, method = "dgesdd")
     W <- sW$u %*% diag(1/sW$d) %*% t(sW$u) %*% W
     W1 <- W
     lim <- rep(1000, maxit)
@@ -199,7 +199,7 @@ ica.R.par <- function (X, n.comp, tol, fun, alpha, maxit, verbose, w.init)
             g.wx <- alpha * (1 - (gwx)^2)
             v2 <- diag(apply(g.wx, 1, FUN = mean)) %*% W
             W1 <- v1 - v2
-            sW1 <- svd(W1)
+            sW1 <- La.svd(W1, method = "dgesdd")
             W1 <- sW1$u %*% diag(1/sW1$d) %*% t(sW1$u) %*% W1
             lim[it + 1] <- max(Mod(Mod(diag(W1 %*% t(W))) - 1))
             W <- W1
@@ -217,7 +217,7 @@ ica.R.par <- function (X, n.comp, tol, fun, alpha, maxit, verbose, w.init)
             g.wx <- (1 - wx^2) * exp(-(wx^2)/2)
             v2 <- diag(apply(g.wx, 1, FUN = mean)) %*% W
             W1 <- v1 - v2
-            sW1 <- svd(W1)
+            sW1 <- La.svd(W1, method = "dgesdd")
             W1 <- sW1$u %*% diag(1/sW1$d) %*% t(sW1$u) %*% W1
             lim[it + 1] <- max(Mod(Mod(diag(W1 %*% t(W))) - 1))
             W <- W1
